@@ -66,7 +66,7 @@
 #define GLwDrawingAreaRec                GLwMDrawingAreaRec
 #endif 
 
-#define ATTRIBLIST_SIZE 30
+#define ATTRIBLIST_SIZE 32
 
 #define offset(field) XtOffset(GLwDrawingAreaWidget,glwDrawingArea.field)
 
@@ -347,7 +347,7 @@ WidgetClass glwDrawingAreaWidgetClass=(WidgetClass)&glwDrawingAreaClassRec;
 
 
 
-static error(Widget w,char* string){
+static void error(Widget w,char* string){
   char buf[100];
 #ifdef __GLX_MOTIF
   sprintf(buf,"GLwMDrawingArea: %s\n",string);
@@ -358,7 +358,7 @@ static error(Widget w,char* string){
   }
 
 
-static warning(Widget w,char* string){
+static void warning(Widget w,char* string){
   char buf[100];
 #ifdef __GLX_MOTIF
   sprintf (buf, "GLwMDraw: %s\n", string);
